==> fcrepo-server-3.5-sources.jar: org/fcrepo/server/rest/RestParam.java <==
/* The contents of this file are subject to the license and copyright terms
 * detailed in the license directory at the root of the source tree (also
 * available online at http://fedora-commons.org/license/).
 */
package org.fcrepo.server.rest;

public interface RestParam {
    String FORCE = "force";
    String AS_OF_DATE_TIME = "asOfDateTime";
    String LABEL = "label";
    String STATE = "state";
    String OWNER_ID = "ownerId";
    String ENCODING = "encoding";
    String FORMAT = "format";
    String CONTENT_MODEL = "contentModel";
    String LOG_MESSAGE = "logMessage";
    String VERSIONABLE = "versionable";
    String DS_LOCATION = "dsLocation";
    String CONTROL_GROUP = "controlGroup";
    String ALT_IDS = "altIDs";
    String DS_LABEL = "dsLabel";
    String DS_STATE = "dsState";
    String FORMAT_URI = "formatURI";
    String CHECKSUM_TYPE = "checksumType";
    String CHECKSUM = "checksum";
    String VALIDATE_CHECKSUM = "validateChecksum";
    String END_DT = "endDT";
    String START_DT = "startDT";
    String NAMESPACE = "namespace";
    String EXPORT_CONTEXT = "context";
    String DSID = "dsID";
    String PID = "pid";
    String SDEF = "sDef";
    String METHOD = "method";
    String MIME_TYPE = "mimeType";
    String IGNORE_CONTENT = "ignoreContent";
    String IGNORE_MIME = "ignoreMime";
    String DOWNLOAD = "download";

    String SUBJECT = "subject";
    String PREDICATE = "predicate";
    String OBJECT = "object";
    String IS_LITERAL = "isLiteral";
    String DATATYPE = "datatype";
    String LAST_MODIFIED_DATE = "lastModifiedDate";
}

==> fcrepo-server-3.6-sources.jar: org/fcrepo/server/rest/RestParam.java <==
/* The contents of this file are subject to the license and copyright terms
 * detailed in the license directory at the root of the source tree (also
 * available online at http://fedora-commons.org/license/).
 */
package org.fcrepo.server.rest;

public interface RestParam {
    String FORCE = "force";
    String AS_OF_DATE_TIME = "asOfDateTime";
    String LABEL = "label";
    String STATE = "state";
    String OWNER_ID = "ownerId";
    String ENCODING = "encoding";
    String FORMAT = "format";
    String CONTENT_MODEL = "contentModel";
    String LOG_MESSAGE = "logMessage";
    String VERSIONABLE = "versionable";
    String DS_LOCATION = "dsLocation";
    String CONTROL_GROUP = "controlGroup";
    String ALT_IDS = "altIDs";
    String DS_LABEL = "dsLabel";
    String DS_STATE = "dsState";
    String FORMAT_URI = "formatURI";
    String CHECKSUM_TYPE = "checksumType";
    String CHECKSUM = "checksum";
    String VALIDATE_CHECKSUM = "validateChecksum";
    String END_DT = "endDT";
    String START_DT = "startDT";
    String NAMESPACE = "namespace";
    String EXPORT_CONTEXT = "context";
    String DSID = "dsID";
    String PID = "pid";
    String SDEF = "sDef";
    String METHOD = "method";
    String MIME_TYPE = "mimeType";
    String IGNORE_CONTENT = "ignoreContent";
    String IGNORE_MIME = "ignoreMime";
    String DOWNLOAD = "download";
    // relationships params
    String SUBJECT = "subject";
    String PREDICATE = "predicate";
    String OBJECT = "object";
    String IS_LITERAL = "isLiteral";
    String DATATYPE = "datatype";
    String LAST_MODIFIED_DATE = "lastModifiedDate";
    // object search params
    String TERMS = "terms";
    String QUERY = "query";
    String MAX_RESULTS = "maxResults";
    String SESSION_TOKEN = "sessionToken";
    String RESULT_FORMAT = "resultFormat";
    // common flash override param
    String FLASH = "flash";
    String PROFILES = "profiles";
}
